% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/games.R
\name{sample_gnm}
\alias{sample_gnm}
\alias{gnm}
\title{Generate random graphs according to the \eqn{G(n,m)} Erdős-Rényi model}
\usage{
sample_gnm(n, m, directed = FALSE, loops = FALSE)

gnm(...)
}
\arguments{
\item{n}{The number of vertices in the graph.}

\item{m}{The number of edges in the graph.}

\item{directed}{Logical, whether the graph will be directed, defaults to
\code{FALSE}.}

\item{loops}{Logical, whether to add loop edges, defaults to \code{FALSE}.}

\item{...}{Passed to \code{sample_gnm()}.}
}
\value{
A graph object.
}
\description{
Random graph with a fixed number of edges and vertices.
}
\details{
The graph has \code{n} vertices and \code{m} edges. The edges are chosen uniformly
at random from the set of all vertex pairs. This set includes potential
self-connections as well if the \code{loops} parameter is \code{TRUE}.
}
\examples{

g <- sample_gnm(1000, 1000)
degree_distribution(g)
}
\references{
Erdős, P. and Rényi, A., On random graphs, \emph{Publicationes
Mathematicae} 6, 290--297 (1959).
}
\seealso{
Random graph models (games)
\code{\link{erdos.renyi.game}()},
\code{\link{sample_}()},
\code{\link{sample_bipartite}()},
\code{\link{sample_correlated_gnp}()},
\code{\link{sample_correlated_gnp_pair}()},
\code{\link{sample_degseq}()},
\code{\link{sample_dot_product}()},
\code{\link{sample_fitness}()},
\code{\link{sample_fitness_pl}()},
\code{\link{sample_forestfire}()},
\code{\link{sample_gnp}()},
\code{\link{sample_grg}()},
\code{\link{sample_growing}()},
\code{\link{sample_hierarchical_sbm}()},
\code{\link{sample_islands}()},
\code{\link{sample_k_regular}()},
\code{\link{sample_last_cit}()},
\code{\link{sample_pa}()},
\code{\link{sample_pa_age}()},
\code{\link{sample_pref}()},
\code{\link{sample_sbm}()},
\code{\link{sample_smallworld}()},
\code{\link{sample_traits_callaway}()},
\code{\link{sample_tree}()}
}
\author{
Gabor Csardi \email{csardi.gabor@gmail.com}
}
\concept{games}
\keyword{graphs}
